@@ -1,3 +1,5 @@
+import numpy as np
+
 def gen(target: list[any]) -> any:
     """
     This function is a generator.
@@ -6,6 +8,6 @@ def gen(target: list[any]) -> any:
     ----------
     target (list) : target list.
     """
-    assert isinstance(target, list), "target must be a list."
+    assert isinstance(target, list | np.ndarray), "target must be a list or numpy.ndarray."
     for i in target:
         yield i
\ No newline at end of file
